pub struct VmWait { /* private fields */ }Implementations
Sourceimpl VmWait
impl VmWait
pub fn block_generation(&self) -> u64
pub fn needs_runtime_poll(&self) -> bool
pub fn poll( &mut self, stack: &mut Vec<Value>, bgm: &mut BgmEngine, koe: &mut KoeEngine, se: &mut SeEngine, pcm: &mut PcmEngine, globals: &mut GlobalState, ids: &RuntimeConstants, ) -> bool
pub fn is_blocked( &mut self, bgm: &mut BgmEngine, koe: &mut KoeEngine, se: &mut SeEngine, pcm: &mut PcmEngine, globals: &mut GlobalState, ids: &RuntimeConstants, ) -> bool
pub fn wait_system_modal(&mut self)
pub fn finish_system_modal(&mut self, value: Value)
pub fn finish_system_modal_void(&mut self)
pub fn system_modal_active(&self) -> bool
pub fn wait_ms(&mut self, ms: u64)
pub fn wait_next_frame(&mut self, current_frame: u64)
Sourcepub fn wait_ms_key(&mut self, ms: u64)
pub fn wait_ms_key(&mut self, ms: u64)
Wait for a duration, but allow any key/mouse press to cancel the wait.
pub fn wait_key(&mut self)
pub fn wait_audio(&mut self, w: AudioWait, key: bool)
pub fn wait_audio_with_return( &mut self, w: AudioWait, key: bool, return_value_flag: bool, )
pub fn wait_object_all_events( &mut self, stage_form_id: u32, stage_idx: i64, runtime_slot: usize, key_skip: bool, )
pub fn wait_object_event( &mut self, stage_form_id: u32, stage_idx: i64, runtime_slot: usize, op: i32, key_skip: bool, return_value_flag: bool, )
pub fn wait_object_event_list( &mut self, stage_form_id: u32, stage_idx: i64, runtime_slot: usize, list_op: i32, list_idx: usize, key_skip: bool, return_value_flag: bool, )
pub fn wait_global_movie(&mut self, key_skip: bool, return_value_flag: bool)
pub fn wait_object_movie( &mut self, stage_form_id: u32, stage_idx: i64, runtime_slot: usize, key_skip: bool, return_value_flag: bool, )
pub fn wait_generic_int_event( &mut self, form_id: u32, index: Option<usize>, key_skip: bool, return_value_flag: bool, )
pub fn wait_fog_x_event(&mut self, key_skip: bool, return_value_flag: bool)
pub fn wait_counter( &mut self, form_id: u32, index: usize, target: i64, key_skip: bool, return_value_flag: bool, )
pub fn wait_wipe(&mut self, key_skip: bool)
Sourcepub fn notify_key(
&mut self,
_globals: &mut GlobalState,
_ids: &RuntimeConstants,
) -> bool
pub fn notify_key( &mut self, _globals: &mut GlobalState, _ids: &RuntimeConstants, ) -> bool
Notify the wait system that a key/mouse input happened.
Returns true if the input is interpreted as a wipe-skip (used by WIPE/WAIT_WIPE).
Sourcepub fn notify_movie_down_up(
&mut self,
globals: &mut GlobalState,
ids: &RuntimeConstants,
result: i64,
) -> bool
pub fn notify_movie_down_up( &mut self, globals: &mut GlobalState, ids: &RuntimeConstants, result: i64, ) -> bool
Notify MOV/OBJECT movie waits that DECIDE/CANCEL completed a down-up pair.
This matches C++ tnm_mov_wait_proc / tnm_obj_mov_wait_proc:
MOV_WAIT_KEY consumes only VK_EX_DECIDE or VK_EX_CANCEL down-up, returning
1 or -1 respectively. Generic key/mouse events must not skip movie waits.
Sourcepub fn take_movie_skip(&mut self) -> Option<MovieWait>
pub fn take_movie_skip(&mut self) -> Option<MovieWait>
If the current wait was skipped via key input, returns the skipped movie wait info.
pub fn clear(&mut self)